@@ -5,7 +5,7 @@
  * Copyright (C) 2015 Pavol Bauer
  * Copyright (C) 2017 -- 2019 Robin Eriksson
  * Copyright (C) 2015 -- 2019 Stefan Engblom
- * Copyright (C) 2015 -- 2019 Stefan Widgren
+ * Copyright (C) 2015 -- 2020 Stefan Widgren
  *
  * SimInf is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  */
 
 #include <Rdefines.h>
-
+#include <R_ext/Visibility.h>
 #include "SimInf.h"
 
 /**
@@ -31,7 +31,7 @@
  * @param arg The arg to check
  * @return 0 if OK, else -1
  */
-int SimInf_arg_check_dgCMatrix(SEXP arg)
+int attribute_hidden SimInf_arg_check_dgCMatrix(SEXP arg)
 {
     SEXP class_name;
 
@@ -49,20 +49,35 @@ int SimInf_arg_check_dgCMatrix(SEXP arg)
  * @param arg The arg to check
  * @return 0 if OK, else -1
  */
-int SimInf_arg_check_integer(SEXP arg)
+int attribute_hidden SimInf_arg_check_integer(SEXP arg)
 {
     if (!Rf_isInteger(arg) || Rf_length(arg) != 1 || NA_INTEGER == INTEGER(arg)[0])
         return -1;
     return 0;
 }
 
+/**
+ * Check that integer argument is greater than zero.
+ *
+ * @param arg The arg to check
+ * @return 0 if OK, else -1
+ */
+int attribute_hidden SimInf_arg_check_integer_gt_zero(SEXP arg)
+{
+    if (SimInf_arg_check_integer(arg))
+        return -1;
+    if (INTEGER(arg)[0] < 1)
+        return -1;
+    return 0;
+}
+
 /**
  * Check matrix argument
  *
  * @param arg The arg to check
  * @return 0 if OK, else -1
  */
-int SimInf_arg_check_matrix(SEXP arg)
+int attribute_hidden SimInf_arg_check_matrix(SEXP arg)
 {
     if (!Rf_isMatrix(arg))
         return -1;
@@ -75,7 +90,7 @@ int SimInf_arg_check_matrix(SEXP arg)
  * @param arg The arg to check
  * @return 0 if OK, else -1
  */
-int SimInf_arg_check_model(SEXP arg)
+int attribute_hidden SimInf_arg_check_model(SEXP arg)
 {
     static const char *valid[] = {"SimInf_model", ""};
 
@@ -95,7 +110,7 @@ int SimInf_arg_check_model(SEXP arg)
  *        in a sparse matrix.
  * @return 1 if data is stored in the sparse matrix, else 0.
  */
-int SimInf_sparse(SEXP m, R_xlen_t i, R_xlen_t j)
+int attribute_hidden SimInf_sparse(SEXP m, R_xlen_t i, R_xlen_t j)
 {
     int *d = INTEGER(GET_SLOT(m, Rf_install("Dim")));
     return d[0] == i && d[1] == j;
