@@ -37,7 +37,8 @@ typedef struct {
     rowinfo_t *a;
 } rowinfo_vec;
 
-static void SimInf_insert_node_time(
+static void
+SimInf_insert_id_time(
     rowinfo_vec *ri,
     SEXP m,
     R_xlen_t m_stride,
@@ -61,7 +62,8 @@ static void SimInf_insert_node_time(
     }
 }
 
-static void SimInf_insert_node_time2(
+static void
+SimInf_insert_id_time2(
     rowinfo_vec *ri,
     SEXP m1,
     SEXP m2,
@@ -110,7 +112,8 @@ static void SimInf_insert_node_time2(
     }
 }
 
-static void SimInf_sparse2df_int(
+static void
+SimInf_sparse2df_int(
     SEXP dst,
     rowinfo_vec *ri,
     SEXP m,
@@ -164,7 +167,9 @@ static void SimInf_sparse2df_int(
                 }
             }
         } else {
-            #pragma omp parallel for num_threads(SimInf_num_threads())
+            #ifdef _OPENMP
+            #  pragma omp parallel for num_threads(SimInf_num_threads())
+            #endif
             for (R_xlen_t t = 0; t < tlen; t++) {
                 R_xlen_t id = 0;
 
@@ -190,7 +195,8 @@ static void SimInf_sparse2df_int(
     }
 }
 
-static void SimInf_sparse2df_real(
+static void
+SimInf_sparse2df_real(
     SEXP dst,
     rowinfo_vec *ri,
     SEXP m,
@@ -244,7 +250,9 @@ static void SimInf_sparse2df_real(
                 }
             }
         } else {
-            #pragma omp parallel for num_threads(SimInf_num_threads())
+            #ifdef _OPENMP
+            #  pragma omp parallel for num_threads(SimInf_num_threads())
+            #endif
             for (R_xlen_t t = 0; t < tlen; t++) {
                 R_xlen_t id = 0;
 
@@ -270,7 +278,8 @@ static void SimInf_sparse2df_real(
     }
 }
 
-static void SimInf_dense2df_int(
+static void
+SimInf_dense2df_int(
     SEXP dst,
     int *m,
     int * m_i,
@@ -278,31 +287,35 @@ static void SimInf_dense2df_int(
     R_xlen_t m_stride,
     R_xlen_t nrow,
     R_xlen_t tlen,
-    R_xlen_t Nnodes,
-    R_xlen_t Nn,
+    R_xlen_t id_len,
+    R_xlen_t id_n,
     R_xlen_t col,
-    int *p_nodes)
+    int *p_id)
 {
     for (R_xlen_t i = 0; i < m_i_len; i++) {
         SEXP vec = PROTECT(Rf_allocVector(INTSXP, nrow));
         int *p_vec = INTEGER(vec);
         int *p_m = m + m_i[i] - 1;
 
-        if (p_nodes != NULL) {
-            /* Note that the node identifiers are one-based. */
-            #pragma omp parallel for num_threads(SimInf_num_threads())
+        if (p_id != NULL) {
+            /* Note that the identifiers are one-based. */
+            #ifdef _OPENMP
+            #  pragma omp parallel for num_threads(SimInf_num_threads())
+            #endif
             for (R_xlen_t t = 0; t < tlen; t++) {
-                for (R_xlen_t node = 0; node < Nnodes; node++) {
-                    p_vec[t * Nnodes + node] =
-                        p_m[(t * Nn + p_nodes[node] - 1) * m_stride];
+                for (R_xlen_t i = 0; i < id_len; i++) {
+                    p_vec[t * id_len + i] =
+                        p_m[(t * id_n + p_id[i] - 1) * m_stride];
                 }
             }
         } else {
-            #pragma omp parallel for num_threads(SimInf_num_threads())
+            #ifdef _OPENMP
+            #  pragma omp parallel for num_threads(SimInf_num_threads())
+            #endif
             for (R_xlen_t t = 0; t < tlen; t++) {
-                for (R_xlen_t node = 0; node < Nnodes; node++) {
-                    p_vec[t * Nnodes + node] =
-                        p_m[(t * Nn + node) * m_stride];
+                for (R_xlen_t i = 0; i < id_len; i++) {
+                    p_vec[t * id_len + i] =
+                        p_m[(t * id_n + i) * m_stride];
                 }
             }
         }
@@ -312,7 +325,8 @@ static void SimInf_dense2df_int(
     }
 }
 
-static void SimInf_dense2df_real(
+static void
+SimInf_dense2df_real(
     SEXP dst,
     double *m,
     int * m_i,
@@ -320,31 +334,35 @@ static void SimInf_dense2df_real(
     R_xlen_t m_stride,
     R_xlen_t nrow,
     R_xlen_t tlen,
-    R_xlen_t Nnodes,
-    R_xlen_t Nn,
+    R_xlen_t id_len,
+    R_xlen_t id_n,
     R_xlen_t col,
-    int *p_nodes)
+    int *p_id)
 {
     for (R_xlen_t i = 0; i < m_i_len; i++) {
         SEXP vec = PROTECT(Rf_allocVector(REALSXP, nrow));
         double *p_vec = REAL(vec);
         double *p_m = m + m_i[i] - 1;
 
-        if (p_nodes != NULL) {
+        if (p_id != NULL) {
             /* Note that the node identifiers are one-based. */
-            #pragma omp parallel for num_threads(SimInf_num_threads())
+            #ifdef _OPENMP
+            #  pragma omp parallel for num_threads(SimInf_num_threads())
+            #endif
             for (R_xlen_t t = 0; t < tlen; t++) {
-                for (R_xlen_t node = 0; node < Nnodes; node++) {
-                    p_vec[t * Nnodes + node] =
-                        p_m[(t * Nn + p_nodes[node] - 1) * m_stride];
+                for (R_xlen_t i = 0; i < id_len; i++) {
+                    p_vec[t * id_len + i] =
+                        p_m[(t * id_n + p_id[i] - 1) * m_stride];
                 }
             }
         } else {
-            #pragma omp parallel for num_threads(SimInf_num_threads())
+            #ifdef _OPENMP
+            #  pragma omp parallel for num_threads(SimInf_num_threads())
+            #endif
             for (R_xlen_t t = 0; t < tlen; t++) {
-                for (R_xlen_t node = 0; node < Nnodes; node++) {
-                    p_vec[t * Nnodes + node] =
-                        p_m[(t * Nn + node) * m_stride];
+                for (R_xlen_t i = 0; i < id_len; i++) {
+                    p_vec[t * id_len + i] =
+                        p_m[(t * id_n + i) * m_stride];
                 }
             }
         }
@@ -369,12 +387,15 @@ static void SimInf_dense2df_real(
  * @param cm_lbl state names of the data in 'cm'.
  * @param tspan a vector of increasing time points for the time
  *        in each column in 'dm' and 'cm'.
- * @param Nn number of nodes in the SimInf_model.
- * @param nodes NULL or an integer vector with (1-based) node
- *        indices of the nodes to include in the data.frame.
+ * @param id_n number of identifiers in the model.
+ * @param id NULL or an integer vector with (1-based) indices of the
+ *        identifiers to include in the data.frame.
+ * @param id_lbl character vector of length one with the name of the
+ *        identifier column.
  * @return A data.frame.
  */
-SEXP attribute_hidden SimInf_trajectory(
+SEXP attribute_hidden
+SimInf_trajectory(
     SEXP dm,
     SEXP dm_i,
     SEXP dm_lbl,
@@ -382,12 +403,13 @@ SEXP attribute_hidden SimInf_trajectory(
     SEXP cm_i,
     SEXP cm_lbl,
     SEXP tspan,
-    SEXP Nn,
-    SEXP nodes)
+    SEXP id_n,
+    SEXP id,
+    SEXP id_lbl)
 {
     SEXP colnames, result, vec;
     int *p_vec;
-    int *p_nodes = Rf_isNull(nodes) ? NULL : INTEGER(nodes);
+    int *p_id = Rf_isNull(id) ? NULL : INTEGER(id);
     R_xlen_t dm_i_len = XLENGTH(dm_i);
     R_xlen_t dm_stride = Rf_isNull(dm_lbl) ? 0 : XLENGTH(dm_lbl);
     int dm_sparse = Rf_isS4(dm) && Rf_inherits(dm, "dgCMatrix") ? 1 : 0;
@@ -395,10 +417,12 @@ SEXP attribute_hidden SimInf_trajectory(
     R_xlen_t cm_stride = Rf_isNull(cm_lbl) ? 0 : XLENGTH(cm_lbl);
     int cm_sparse = Rf_isS4(cm) && Rf_inherits(cm, "dgCMatrix") ? 1 : 0;
     R_xlen_t tlen = XLENGTH(tspan);
-    R_xlen_t c_Nn = Rf_asInteger(Nn);
-    R_xlen_t Nnodes = Rf_isNull(nodes) ? c_Nn : XLENGTH(nodes);
-    R_xlen_t nrow = tlen * Nnodes;
-    R_xlen_t ncol = 2 + dm_i_len + cm_i_len; /* The '2' is for the 'node' and 'time' columns. */
+    R_xlen_t c_id_n = Rf_asInteger(id_n);
+    R_xlen_t id_len = Rf_isNull(id) ? c_id_n : XLENGTH(id);
+    R_xlen_t nrow = tlen * id_len;
+    R_xlen_t ncol = 2 + dm_i_len + cm_i_len; /* The '2' is for the
+                                              * 'identifier' and
+                                              * 'time' columns. */
     rowinfo_vec *ri = NULL;
 
     /* Use all available threads in parallel regions. */
@@ -406,7 +430,7 @@ SEXP attribute_hidden SimInf_trajectory(
 
     /* Create a vector for the column names. */
     PROTECT(colnames = Rf_allocVector(STRSXP, ncol));
-    SET_STRING_ELT(colnames, 0, Rf_mkChar("node"));
+    SET_STRING_ELT(colnames, 0, STRING_ELT(id_lbl, 0));
     SET_STRING_ELT(colnames, 1, Rf_mkChar("time"));
     for (R_xlen_t i = 0; i < dm_i_len; i++) {
         R_xlen_t j = INTEGER(dm_i)[i] - 1;
@@ -420,21 +444,21 @@ SEXP attribute_hidden SimInf_trajectory(
     /* Determine the number of rows that is required for the
      * data.frame. If either U or V is a dense matrix, then we need a
      * full data.frame with one row per node and time point, else the
-     * number of rows depends on unique combinations of node and time
-     * information in the sparse matrices. */
+     * number of rows depends on unique combinations of identifier and
+     * time information in the sparse matrices. */
     if (dm_i_len > 0 && cm_i_len > 0) {
         if (dm_sparse && cm_sparse) {
             ri = calloc(1, sizeof(rowinfo_vec));
-            SimInf_insert_node_time2(ri, dm, cm, dm_stride, cm_stride, tlen);
+            SimInf_insert_id_time2(ri, dm, cm, dm_stride, cm_stride, tlen);
             nrow = kv_size(*ri);
         }
     } else if (dm_i_len > 0 && dm_sparse) {
         ri = calloc(1, sizeof(rowinfo_vec));
-        SimInf_insert_node_time(ri, dm, dm_stride, tlen);
+        SimInf_insert_id_time(ri, dm, dm_stride, tlen);
         nrow = kv_size(*ri);
     } else if (cm_i_len > 0 && cm_sparse) {
         ri = calloc(1, sizeof(rowinfo_vec));
-        SimInf_insert_node_time(ri, cm, cm_stride, tlen);
+        SimInf_insert_id_time(ri, cm, cm_stride, tlen);
         nrow = kv_size(*ri);
     }
 
@@ -448,29 +472,35 @@ SEXP attribute_hidden SimInf_trajectory(
      * one-based. */
     PROTECT(vec = Rf_allocVector(INTSXP, nrow));
     p_vec = INTEGER(vec);
-    #pragma omp parallel for num_threads(SimInf_num_threads())
+    #ifdef _OPENMP
+    #  pragma omp parallel for num_threads(SimInf_num_threads())
+    #endif
     for (R_xlen_t i = 0; i < nrow; i++) {
         p_vec[i] = i + 1;
     }
     Rf_setAttrib(result, R_RowNamesSymbol, vec);
     UNPROTECT(1);
 
-    /* Add a 'node' identifier column to the 'data.frame'. */
+    /* Add an identifier column to the 'data.frame'. */
     PROTECT(vec = Rf_allocVector(INTSXP, nrow));
     p_vec = INTEGER(vec);
     if (ri) {
         for (size_t i = 0; i < kv_size(*ri); i++)
             p_vec[i] = kv_A(*ri, i).id + 1;
-    } else if (p_nodes != NULL) {
-        #pragma omp parallel for num_threads(SimInf_num_threads())
+    } else if (p_id != NULL) {
+        #ifdef _OPENMP
+        #  pragma omp parallel for num_threads(SimInf_num_threads())
+        #endif
         for (R_xlen_t t = 0; t < tlen; t++) {
-            memcpy(&p_vec[t * Nnodes], p_nodes, Nnodes * sizeof(int));
+            memcpy(&p_vec[t * id_len], p_id, id_len * sizeof(int));
         }
     } else {
-        #pragma omp parallel for num_threads(SimInf_num_threads())
+        #ifdef _OPENMP
+        #  pragma omp parallel for num_threads(SimInf_num_threads())
+        #endif
         for (R_xlen_t t = 0; t < tlen; t++) {
-            for (R_xlen_t node = 0; node < Nnodes; node++)
-                p_vec[t * Nnodes + node] = node + 1;
+            for (R_xlen_t i = 0; i < id_len; i++)
+                p_vec[t * id_len + i] = i + 1;
         }
     }
     SET_VECTOR_ELT(result, 0, vec);
@@ -487,10 +517,12 @@ SEXP attribute_hidden SimInf_trajectory(
             for (size_t i = 0; i < kv_size(*ri); i++)
                 p_vec[i] = p_tspan[kv_A(*ri, i).time];
         } else {
-            #pragma omp parallel for num_threads(SimInf_num_threads())
+            #ifdef _OPENMP
+            #  pragma omp parallel for num_threads(SimInf_num_threads())
+            #endif
             for (R_xlen_t t = 0; t < tlen; t++) {
-                for (R_xlen_t node = 0; node < Nnodes; node++)
-                    p_vec[t * Nnodes + node] = p_tspan[t];
+                for (R_xlen_t i = 0; i < id_len; i++)
+                    p_vec[t * id_len + i] = p_tspan[t];
             }
         }
 
@@ -506,8 +538,8 @@ SEXP attribute_hidden SimInf_trajectory(
                 SET_STRING_ELT(vec, i, STRING_ELT(lbl_tspan, kv_A(*ri, i).time));
         } else {
             for (R_xlen_t t = 0; t < tlen; t++) {
-                for (R_xlen_t node = 0; node < Nnodes; node++)
-                    SET_STRING_ELT(vec, t * Nnodes + node, STRING_ELT(lbl_tspan, t));
+                for (R_xlen_t i = 0; i < id_len; i++)
+                    SET_STRING_ELT(vec, t * id_len + i, STRING_ELT(lbl_tspan, t));
             }
         }
 
@@ -518,19 +550,19 @@ SEXP attribute_hidden SimInf_trajectory(
     /* Copy data from the discrete state matrix. */
     if (dm_sparse) {
         SimInf_sparse2df_int(result, ri, dm, INTEGER(dm_i), dm_i_len,
-                             dm_stride, nrow, tlen, Nnodes, 2);
+                             dm_stride, nrow, tlen, id_len, 2);
     } else {
         SimInf_dense2df_int(result, INTEGER(dm), INTEGER(dm_i), dm_i_len,
-                            dm_stride, nrow, tlen, Nnodes, c_Nn, 2, p_nodes);
+                            dm_stride, nrow, tlen, id_len, c_id_n, 2, p_id);
     }
 
     /* Copy data from the continuous state matrix. */
     if (cm_sparse) {
         SimInf_sparse2df_real(result, ri, cm, INTEGER(cm_i), cm_i_len,
-                              cm_stride, nrow, tlen, Nnodes, 2 + dm_i_len);
+                              cm_stride, nrow, tlen, id_len, 2 + dm_i_len);
     } else {
         SimInf_dense2df_real(result, REAL(cm), INTEGER(cm_i), cm_i_len, cm_stride,
-                             nrow, tlen, Nnodes, c_Nn, 2 + dm_i_len, p_nodes);
+                             nrow, tlen, id_len, c_id_n, 2 + dm_i_len, p_id);
     }
 
     if (ri) {
